%-------------------------------------------------------------------------%
% VERIFICATION OF AN AGENT-BASED DISEASE MODEL OF HUMAN MYCOBACTERIUM TUBERCULOSIS INFECTION
% Cristina Curreli*, Francesco Pappalardo, Giulia Russo, Marzio Pennisi, Dimitrios Kiagias, Miguel Juarez, Marco Viceconti
%
% Smoothness analsysis
% Inputs: 
% - results obtained from the TimeStepConvergenceAnalysis (11_OVs_RawData.csv.csv) 
% Outputs: 
% - smoothness measure D for each of the OVs series data (_Summary_D.csv) 
% - first discrete derivative for each of the OVs series data (_Summary_FirstDer.csv)
%
%    Author: Cristina Curreli, 2020
%    email: *cristina.curreli@unibo.it
%-------------------------------------------------------------------------%
%% Script Inputs

clear all
close all
clc

%select the folder where you saved the simulation results related to the
%smoothness analysis
pathfile = uigetdir ();

%create new folder with results
FolderResults = "_Results";
mkdir _Results
PathResults = fullfile(pathfile,FolderResults);

%names of the simulation result file where the OVs are saved
namefile = '11_OVs_RawData.csv';
data = importdata(namefile);
Rawdata = data.data;

time = data.data(:,1);
TH17data = data.data(:,2);
ABdata = data.data(:,3);
Bdata = data.data(:,4);
totAGSdata = data.data(:,5);

D = zeros(length(time),4);
for j = 1:4
    for i=4:(length(time)-4)
        data_wind = Rawdata(i-3:i+3,j+1);
        D_local = std(diff(data_wind)/abs(mean(diff(data_wind))));
        if isnan(D_local)
            D_local=0;
        end
        D(i,j) = D_local;
    end
end

FirstDer_Th17 = diff(Rawdata(:,2));
FirstDer_AB = diff(Rawdata(:,3));
FirstDer_B = diff(Rawdata(:,4));
FirstDer_totAGS = diff(Rawdata(:,5));
FirstDer = [FirstDer_Th17 FirstDer_AB FirstDer_B FirstDer_totAGS];

    
table_D = array2table (D);
table_D.Properties.VariableNames = {'D_ThAct17','D_Ab','D_Btot','D_AGStot'};
writetable(table_D,fullfile(PathResults, '_Summary_D.csv'),'WriteVariableNames',true);       
table_FirstDer = array2table (FirstDer);
table_FirstDer.Properties.VariableNames = {'D_ThAct17','D_Ab','D_Btot','D_AGStot'};
writetable(table_FirstDer,fullfile(PathResults, '_Summary_FirstDer.csv'),'WriteVariableNames',true);       


