% VERIFICATION OF AN AGENT-BASED DISEASE MODEL OF HUMAN MYCOBACTERIUM TUBERCULOSIS INFECTION
% Cristina Curreli*, Francesco Pappalardo, Giulia Russo, Marzio Pennisi, Dimitrios Kiagias, Miguel Juarez, Marco Viceconti
%
% LHS for UISS-TB parameter sweep
% I considered the N' = 10 inputs that affect the simulation results. 
% Number of P values was set to 100 
% based on: https://it.mathworks.com/matlabcentral/fileexchange/45793-latin-hypercube
%    Author: Cristina Curreli, 2020
%    email: *cristina.curreli@unibo.it
%-------------------------------------------------------------------------%

clear all
close all
clc

% inputs 
MtbVir = [0:1]; 
MtbSputum = [0:0.1:10000];
Th1 =	[0:0.1:100]; %1
Th2 =	[0:0.1:100]; %2
IgG =	[0:0.1:512];
TC =	[0:0.1:1134]; %3
IL_1 =	[0:0.1:235]; %4
IL_2 =	[0:0.1:894]; %5
IL_10 =	[0:0.1:516]; %6
IL_12 =	[0:0.1:495]; %7
IL17_A =[0:0.1:704]; %8
IL_23 =	[0:0.1:800]; %9
IFN1A =	[0:0.1:148.4]; %10
IFN1B =	[0:0.1:206]; %11
IFNG =	[0:0.1:49.4]; %12
TNF =	[0:0.1:268.2]; %13
LXA4 =	[0:0.1:3.0];
PGE2 =	[0:0.1:2.1];
VitaminD =	[25:0.1:80]; 
Treg =	[0:0.1:200]; 
AGE =	[10:1:80];
BMI =	[18:0.1:35];

minVect = [min(MtbVir); min(Th1);min(Th2);min(IgG); min(TC);min(IL_12);....
    min(PGE2);min(Treg);min(AGE);min(BMI)];
maxVect = [max(MtbVir); max(Th1);max(Th2);max(IgG); max(TC);max(IL_12);....
    max(PGE2);max(Treg);max(AGE);max(BMI)];

slope=maxVect-minVect;
offset=minVect;

p=length(minVect);
n = 100;
SLOPE=ones(n,p);
OFFSET=ones(n,p);

for i=1:p
    SLOPE(:,i)=ones(n,1).*slope(i);
    OFFSET(:,i)=ones(n,1).*offset(i);
end
X_normalized = lhsdesign(n,p);
X_scaled=SLOPE.*X_normalized+OFFSET; % table used to generate setup input for the P=100 simulations

