% VERIFICATION OF AN AGENT-BASED DISEASE MODEL OF HUMAN MYCOBACTERIUM TUBERCULOSIS INFECTION
% Cristina Curreli*, Francesco Pappalardo, Giulia Russo, Marzio Pennisi, Dimitrios Kiagias, Miguel Juarez, Marco Viceconti
%
% Parameter Sweep Analsysis - LHS
% Inputs: 
% - Summary files obtained perturbing each input once at a time from their minimum to their maximum value
% Outputs:
% - Matrix of NI x M0 coefficient pv,j  - see Eq. 2 of the paper (_Summary_P.csv) 
% - A list of the inputs that mostly affect the outputs used for the LHS sampling (_InputsXLHS.csv) 
%
%    Author: Cristina Curreli, 2020
%    email: *cristina.curreli@unibo.it
%-------------------------------------------------------------------------%
%% LHS Analysis

clear all
close all
clc

%select the folder where you have your data
pathfile = uigetdir ();
% [~,basename,~]=fileparts(pathfile);
currentFolder = pathfile

FolderResults = "_Results";
PathResults = fullfile(pathfile,FolderResults);


n=100; % 44 (2xNI) simulations
m = 14; % M0+ 2(time step and number iterations)
nn = 12;

Summary = zeros(n,m);

BaseDataFileName1='_summary.csv';
Folder = fullfile(currentFolder,'LHS');
for k=1:n
File = [num2str(k),BaseDataFileName1];
filename = fullfile(Folder,File);
Summary_n = table2array(readtable(filename,'HeaderLines',1));
Summary (k,:) = Summary_n;
end
Summary = Summary (:,3:end);

Ave_Std = zeros(nn,3);
for kk=1:nn
Ave_l = mean(Summary(:,kk));
Ave_Std(kk,1) = Ave_l;
Std_l = std(Summary(:,kk));
Ave_Std(kk,2) = Std_l;
end

CoV_l = (Ave_Std(:,2)./Ave_Std(:,1))*100;

Cvariation = CoV_l'

table_Cvariation = array2table (Cvariation);
table_Cvariation.Properties.VariableNames = {'PV_ThAct17','PV_Ab','PV_Btot','PV_AGStot',....
    'TimePV_ThAct17','TimePV_Ab','TimePV_Btot','TimePV_AGStot','FV_ThAct17','FV_Ab','FV_Btot','FV_AGStot'};

writetable(table_Cvariation,fullfile(PathResults, '_Summary_C.csv'),'WriteVariableNames',true);       

p_mean = zeros(nn,1);
for iii=1:nn
    Pmean = mean(p_coef(iii,:));
    p_mean(iii)=Pmean;
end
table_p_mean = array2table (p_mean);
table_p_mean.Properties.RowNames = {'MtbVir' ,'MtbSputum', 'Th1', 'Th2', 'IgG', 'TC', 'IL_1', 'IL_2', 'IL_10', 'IL_12', 'IL17_A', 'IL_23', 'IFN1A', 'IFN1B',...
    'IFNG', 'TNF', 'LXA4', 'PGE2', 'VitaminD', 'Treg' ,'AGE', 'BMI'};
table_p_mean_order = sortrows(table_p_mean); %the last -> 10 input variables that mostly affect the output results
table_p_mean_order_write = table_p_mean_order(13:end,:);
InputsXLHS = table_p_mean_order_write.Properties.RowNames;
writetable(array2table(InputsXLHS),fullfile(PathResults, '_InputsXLHS.csv'),'WriteVariableNames',false);       