% VERIFICATION OF AN AGENT-BASED DISEASE MODEL OF HUMAN MYCOBACTERIUM TUBERCULOSIS INFECTION
% Cristina Curreli*, Francesco Pappalardo, Giulia Russo, Marzio Pennisi, Dimitrios Kiagias, Miguel Juarez, Marco Viceconti
%
% Parameter Sweep Analsysis - OAT
% Inputs: 
% - Summary files obtained perturbing each input once at a time from their minimum to their maximum value
% Outputs:
% - Matrix of NI x M0 coefficient pv,j  - see Eq. 2 of the paper (_Summary_P.csv) 
% - A list of the inputs that mostly affect the outputs used for the LHS sampling (_InputsXLHS.csv) 
%
%    Author: Cristina Curreli, 2020
%    email: *cristina.curreli@unibo.it
%-------------------------------------------------------------------------%
%% Once at Time Analysis

clear all
close all
clc

%select the folder where you have your data
pathfile = uigetdir ();
% [~,basename,~]=fileparts(pathfile);
currentFolder = pathfile

%create new folder with results
FolderResults = "_Results";
mkdir _Results
PathResults = fullfile(pathfile,FolderResults);


n=44; % 44 (2xNI) simulations
m = 14; % M0+ 2(time step and number iterations)

Summary = zeros(n,m);

BaseDataFileName1='_summary.csv';
Folder = fullfile(currentFolder,'OAT');
for k=1:n
File = [num2str(k),BaseDataFileName1];
filename = fullfile(Folder,File);
Summary_n = table2array(readtable(filename,'HeaderLines',1));
Summary (k,:) = Summary_n;
end

% solution obtained using as input setup the mean values for each of the NI inputs
BaseDataFileName_Med='45_summary.csv';
filename_med = fullfile(Folder,BaseDataFileName_Med);
Summary_med = table2array(readtable(filename_med,'HeaderLines',1));


MtbVir = [0:1]; 
MtbSputum = [0:0.1:10000];
Th1 =	[0:0.1:100]; %1
Th2 =	[0:0.1:100]; %2
IgG =	[0:0.1:512];
TC =	[0:0.1:1134]; %3
IL_1 =	[0:0.1:235]; %4
IL_2 =	[0:0.1:894]; %5
IL_10 =	[0:0.1:516]; %6
IL_12 =	[0:0.1:495]; %7
IL17_A =[0:0.1:704]; %8
IL_23 =	[0:0.1:800]; %9
IFN1A =	[0:0.1:148.4]; %10
IFN1B =	[0:0.1:206]; %11
IFNG =	[0:0.1:49.4]; %12
TNF =	[0:0.1:268.2]; %13
LXA4 =	[0:0.1:3.0];
PGE2 =	[0:0.1:2.1];
VitaminD =	[25:0.1:80]; 
Treg =	[0:0.1:200]; 
AGE =	[10:1:80];
BMI =	[18:0.1:35]; 

% vector of mean values for Inputs (Ii_max + Ii_min)/2
Vect_med = [(max(MtbVir)+min(MtbVir))/2; (max(MtbSputum)+min(MtbSputum))/2; (max(Th1)+min(Th1))/2;....
    (max(Th2)+min(Th2))/2;(max(IgG)+min(IgG))/2; (max(TC)+min(TC))/2;....
    (max(IL_1)+min(IL_1))/2;(max(IL_2)+min(IL_2))/2;(max(IL_10)+min(IL_10))/2;(max(IL_12)+min(IL_12))/2;....
   (max(IL17_A)+ min(IL17_A))/2;(max(IL_23)+min(IL_23))/2;(max(IFN1A)+min(IFN1A))/2;(max(IFN1B)+min(IFN1B))/2;...
    (max(IFNG)+min(IFNG))/2;(max(TNF)+min(TNF))/2;(max(LXA4)+min(LXA4))/2;(max(PGE2)+min(PGE2))/2;(max(VitaminD)+min(VitaminD))/2;....
    (max(Treg)+min(Treg))/2;(max(AGE)+min(AGE))/2;(max(BMI)+min(BMI))/2];

% vector of (Ii_max - Ii_min) 
Vect_I= [(max(MtbVir)-min(MtbVir)); (max(MtbSputum)-min(MtbSputum)) ; (max(Th1)-min(Th1)) ;....
    (max(Th2)-min(Th2)) ;(max(IgG)-min(IgG)) ; (max(TC)-min(TC)) ;....
    (max(IL_1)-min(IL_1)) ;(max(IL_2)-min(IL_2)) ;(max(IL_10)-min(IL_10)) ;(max(IL_12)-min(IL_12)) ;....
   (max(IL17_A)- min(IL17_A)) ;(max(IL_23)-min(IL_23)) ;(max(IFN1A)-min(IFN1A)) ;(max(IFN1B)-min(IFN1B)) ;...
    (max(IFNG)-min(IFNG)) ;(max(TNF)-min(TNF)) ;(max(LXA4)-min(LXA4)) ;(max(PGE2)-min(PGE2)) ;(max(VitaminD)-min(VitaminD)) ;....
    (max(Treg)-min(Treg)) ;(max(AGE)-min(AGE)) ;(max(BMI)-min(BMI)) ];

nn = 22;
mm = 12;
p_coef = zeros(nn,mm);

add = 0;
for i_n=1:nn
        for i_m=1:mm
            i_nn = i_n+add;
            beta = abs((Summary(i_nn,i_m+2)-Summary(i_nn+1,i_m+2))/(Vect_I(i_n)));
            if beta == 0
                p_coef (i_n,i_m) = beta;
            else
                beta_norm = abs(((Summary(i_nn,i_m+2)-Summary(i_nn+1,i_m+2))/Summary_med(i_m+2))/(Vect_I(i_n)/Vect_med(i_n)));
                p_coef (i_n,i_m) = beta_norm;
            end
        end
        add = add+1;
end

table_P = array2table (p_coef);
table_P.Properties.VariableNames = {'PV_ThAct17','PV_Ab','PV_Btot','PV_AGStot',....
    'TimePV_ThAct17','TimePV_Ab','TimePV_Btot','TimePV_AGStot','FV_ThAct17','FV_Ab','FV_Btot','FV_AGStot'};
table_P.Properties.RowNames = {'MtbVir' ,'MtbSputum', 'Th1', 'Th2', 'IgG', 'TC', 'IL_1', 'IL_2', 'IL_10', 'IL_12', 'IL17_A', 'IL_23', 'IFN1A', 'IFN1B',...
    'IFNG', 'TNF', 'LXA4', 'PGE2', 'VitaminD', 'Treg' ,'AGE', 'BMI'};

writetable(table_P,fullfile(PathResults, '_Summary_P.csv'),'WriteVariableNames',true,'WriteRowNames',true);       

p_mean = zeros(nn,1);
for iii=1:nn
    Pmean = mean(p_coef(iii,:));
    p_mean(iii)=Pmean;
end
table_p_mean = array2table (p_mean);
table_p_mean.Properties.RowNames = {'MtbVir' ,'MtbSputum', 'Th1', 'Th2', 'IgG', 'TC', 'IL_1', 'IL_2', 'IL_10', 'IL_12', 'IL17_A', 'IL_23', 'IFN1A', 'IFN1B',...
    'IFNG', 'TNF', 'LXA4', 'PGE2', 'VitaminD', 'Treg' ,'AGE', 'BMI'};
table_p_mean_order = sortrows(table_p_mean); %the last -> 10 input variables that mostly affect the output results
table_p_mean_order_write = table_p_mean_order(13:end,:);
InputsXLHS = table_p_mean_order_write.Properties.RowNames;
writetable(array2table(InputsXLHS),fullfile(PathResults, '_InputsXLHS.csv'),'WriteVariableNames',false);       