% VERIFICATION OF AN AGENT-BASED DISEASE MODEL OF HUMAN MYCOBACTERIUM TUBERCULOSIS INFECTION
% Cristina Curreli*, Francesco Pappalardo, Giulia Russo, Marzio Pennisi, Dimitrios Kiagias, Miguel Juarez, Marco Viceconti
%
% Obtaining 
% Inputs: 
% - StochasticSummary.csv file
% Outputs:
% - Statistic summary for all the output distributions in term of mean, standard deviation, median, 75 and 25 percentiles (BasicStat.csv). Tab.4*
% - Trend of the IC index (see Eq. 5 of the paper) with increasing values of simulation run for all the 12 outputs (IC.csv). Fig.5*
%   
%    Author: Cristina Curreli, 2020
%    email: *cristina.curreli@unibo.it
%-------------------------------------------------------------------------%
%% Consistency

clear all
close all
clc

pathfile = uigetdir ();
% [~,basename,~]=fileparts(pathfile);
currentFolder = pathfile

%create new folder with results
FolderResults = "_Results";
mkdir _Results
PathResults = fullfile(pathfile,FolderResults);


namefile = 'StochasticSummary.csv';
filename = fullfile(pathfile,namefile);
StochasticSummary = importdata(filename);

n = 1000;
mm = 12;

Summary = zeros(n,mm);
PV_Th17 = StochasticSummary.data(:,3);
Summary(:,1) = PV_Th17;
PV_Ab = StochasticSummary.data(:,4);
Summary(:,2) = PV_Ab;
PV_B = StochasticSummary.data(:,5);
Summary(:,3) = PV_B;
PV_TotAGS = StochasticSummary.data(:,6);
Summary(:,4) = PV_TotAGS;
TPV_Th17 = StochasticSummary.data(:,7)/3600;
Summary(:,5) = TPV_Th17;
TPV_Ab = StochasticSummary.data(:,8)/3600;
Summary(:,6) = TPV_Ab;
TPV_B = StochasticSummary.data(:,9)/3600;
Summary(:,7) = TPV_B;
TPV_TotAGS = StochasticSummary.data(:,10)/3600;
Summary(:,8) = TPV_TotAGS;
FV_Th17 = StochasticSummary.data(:,11);
Summary(:,9) = FV_Th17;
FV_Ab = StochasticSummary.data(:,12);
Summary(:,10) = FV_Ab;
FV_B = StochasticSummary.data(:,13);
Summary(:,11) = FV_B;
FV_TotAGS = StochasticSummary.data(:,14);
Summary(:,12) = FV_TotAGS;

% basic statistics
tab_stat_sum_PV = zeros(4,5);
for i = 3:6
    Media = mean(StochasticSummary.data(:,i));
    StDev = std(StochasticSummary.data(:,i));
    Mediana = median(StochasticSummary.data(:,i));
    percent25 = prctile(StochasticSummary.data(:,i),25);
    percent75 = prctile(StochasticSummary.data(:,i),75);
    tab_stat_sum_PV(i-2,:)= [Media StDev Mediana percent25 percent75];
end

tab_stat_sum_TPV = zeros(4,5);
for i = 7:10
    Media = mean((StochasticSummary.data(:,i))/(60*60));
    StDev = std(StochasticSummary.data(:,i)/(60*60));
    Mediana = median(StochasticSummary.data(:,i)/(60*60));
    percent25 = prctile(StochasticSummary.data(:,i)/(60*60),25);
    percent75 = prctile(StochasticSummary.data(:,i)/(60*60),75);
    tab_stat_sum_TPV(i-6,:)= [Media StDev Mediana percent25 percent75];
end   

value1 = zeros(n,1);
tab_stat_sum_FV = zeros(4,5);
for i = 11:14

value = StochasticSummary.data(:,i);
value(value==0) = NaN;
% value = log(value);

    Media = mean(value,'omitnan');
    StDev = std(value,'omitnan');
    Mediana = median(value,'omitnan');
    percent25 = prctile(value,25);
    percent75 = prctile(value,75);
    tab_stat_sum_FV(i-10,:)= [Media StDev Mediana percent25 percent75];
end  

tab_stat_sum = zeros(12,5);
tab_stat_sum (1,:) = tab_stat_sum_PV (1,:);
tab_stat_sum (2,:) = tab_stat_sum_TPV (1,:);
tab_stat_sum (3,:) = tab_stat_sum_FV (1,:);
tab_stat_sum (4,:) = tab_stat_sum_PV (2,:);
tab_stat_sum (5,:) = tab_stat_sum_TPV (2,:);
tab_stat_sum (6,:) = tab_stat_sum_FV (2,:);
tab_stat_sum (7,:) = tab_stat_sum_PV (3,:);
tab_stat_sum (8,:) = tab_stat_sum_TPV (3,:);
tab_stat_sum (9,:) = tab_stat_sum_FV (3,:);
tab_stat_sum (10,:) = tab_stat_sum_PV (4,:);
tab_stat_sum (11,:) = tab_stat_sum_TPV (4,:);
tab_stat_sum (12,:) = tab_stat_sum_FV (4,:);

table_stat_sum = array2table (tab_stat_sum);
table_stat_sum.Properties.VariableNames = {'Mean','StDeviation','Median','Pctl75','Pctl25'};
% table_stat_sum.Properties.RowNames = {'PV_ThAct17'};
table_stat_sum.Properties.RowNames = {'PV_ThAct17','TPV_ThAct17','FV_ThAct17','PV_Ab',....
    'TimePV_Ab','FV_Ab','PV_Btot','TPV_Btot','FV_Btot','PV_AGStot','TimePV_AGStot','FV_AGStot'};
writetable((table_stat_sum),fullfile(PathResults, 'BasicStat.csv'),'WriteVariableNames',true,'WriteRowNames',true);       

%% Sample Size Ns 

CoV= zeros(999,12);
CumMean= zeros(999,12);
CumStd= zeros(999,12);
for j = 1:12
    
    for i = 1:length(CoV)
       cum_mean_i = mean(Summary((1:i),j));
       cum_std_i = std(Summary((1:i),j)); 
       CoV_i = cum_std_i/cum_mean_i;

       cum_mean_i1 = mean(Summary((1:i+1),j));
       cum_std_i1 = std(Summary((1:i+1),j)); 
       CoV_i1 = cum_std_i1/cum_mean_i1;

       CoVi = abs((CoV_i1-CoV_i)/CoV_i);

       CumMean(i,j)=cum_mean_i;
       CumStd(i,j)=cum_std_i;
       CoV(i,j) = CoVi;
    end
end

table_CoV = array2table (CoV);
table_CoV.Properties.VariableNames = {'PV_ThAct17','PV_Ab','PV_Btot','PV_AGStot',....
    'TimePV_ThAct17','TimePV_Ab','TimePV_Btot','TimePV_AGStot','FV_ThAct17','FV_Ab','FV_Btot','FV_AGStot'};
writetable((table_CoV),fullfile(PathResults, 'IC.csv'),'WriteVariableNames',true);       
