% VERIFICATION OF AN AGENT-BASED DISEASE MODEL OF HUMAN MYCOBACTERIUM TUBERCULOSIS INFECTION
% Cristina Curreli*, Francesco Pappalardo, Giulia Russo, Marzio Pennisi, Dimitrios Kiagias, Miguel Juarez, Marco Viceconti
%
% Obtaining "StochasticSummary.csv" file
%    Author: Cristina Curreli, 2020
%    email: *cristina.curreli@unibo.it
%-------------------------------------------------------------------------%
%% 
clear all
close all
clc

%select the foldr where you saved your data
pathfile = uigetdir ();
currentFolder = pathfile

n=999; % CHANGE - depends on the number of simulations we do
m = 14; % CHANGE - depends on the outputs we want to study

Summary = zeros(n,14);

BaseDataFileName='datafile_';
for k=0:n
FolderName=[num2str(k)]

namefileTH = 'TH-data.out';
filenameTH = fullfile(currentFolder,FolderName,namefileTH);
TH = importdata(filenameTH);
THdata = TH.data;
% Convert to output type
Time = THdata(:,1);
ThAct17 = THdata(:,10);
PV_ThAct17 = max(ThAct17);
i_TimePV_ThAct17 = find(ThAct17==PV_ThAct17);
TimePV_ThAct17 = Time(i_TimePV_ThAct17);
FV_ThAct17 = ThAct17(end);
n_iteraz = length (Time);
Time_step = Time(2)

namefileAB = 'Ab-data.out';
filenameAB = fullfile(currentFolder,FolderName,namefileAB);
Ab = importdata(filenameAB);
Abdata = Ab.data;
% Convert to output type
Abtot = Abdata(:,6);
PV_Ab = max(Abtot);
i_TimePV_Ab = find(Abtot==PV_Ab);
TimePV_Ab = Time(i_TimePV_Ab);
FV_Ab = Abtot(end);

namefileB = 'B-data.out';
filenameB = fullfile(currentFolder,FolderName,namefileB);
B = importdata(filenameB);
Bdata = B.data;
% Convert to output type
BMem = Bdata(:,3);
BNotMem = Bdata(:,4);
BAct = Bdata(:,5);
BpresII = Bdata(:,6);
BDuplic = Bdata(:,7);
Bresting = Bdata(:,8);
% Btot = BMem + BNotMem + BAct + BpresII + BDuplic + Bresting;
Btot = BAct;
PV_Btot = max(Btot);
i_TimePV_Btot = find(Btot==PV_Btot);
TimePV_Btot_all = Time(i_TimePV_Btot);
TimePV_Btot = TimePV_Btot_all(1);
FV_Btot = Btot(end);

namefileAGS = 'Ag-data.out';
filenameAGS = fullfile(currentFolder,FolderName,namefileAGS);
AGS = importdata(filenameAGS);
AGSdata = AGS.data;
indiceAGS2max = 5000000/AGS.data(2,1); %5000000 = t dopo il quale sembra ci sia sempre il secondo picco - controllare SEMPRE!
% Convert to output type
AGStot = AGSdata(:,3);
AGStotNew = AGSdata(indiceAGS2max:end,3);
TimeNew = AGSdata(indiceAGS2max:end,1);
PV_AGStot = max(AGStotNew);
i_TimePV_AGS = find(AGStotNew==PV_AGStot);
TimePV_AGStot = TimeNew(i_TimePV_AGS(1));
FV_AGStot = AGStot(end);

table_sum_matrix = [Time_step,n_iteraz,PV_ThAct17,PV_Ab,PV_Btot,PV_AGStot,....
    TimePV_ThAct17,TimePV_Ab,TimePV_Btot,TimePV_AGStot,FV_ThAct17,FV_Ab,FV_Btot,FV_AGStot];
table_summary_p = array2table (table_sum_matrix);

Summary (k+1,:) = table2array(table_summary_p);

end

table_summary = array2table (Summary);
table_summary.Properties.VariableNames = {'Time_step','n_iteraz','PV_ThAct17','PV_Ab','PV_Btot','PV_AGStot',....
    'TimePV_ThAct17','TimePV_Ab','TimePV_Btot','TimePV_AGStot','FV_ThAct17','FV_Ab','FV_Btot','FV_AGStot'};
writetable(table_summary,fullfile(currentFolder, 'StochasticSummary.csv'),'WriteVariableNames',true);    
    
